Crate moosicbox_remote_library

Crate moosicbox_remote_library 

Remote MoosicBox server music library API client.

This crate provides a MusicApi implementation that connects to a remote MoosicBox server over HTTP, allowing you to access and query a remote music library as if it were local.

Example

let api = RemoteLibraryMusicApi::new(
    "http://localhost:8000".to_string(),
    ApiSource::library(),
    "default".to_string(),
);

// Use the API to fetch artists, albums, tracks, etc.
let artists = api.artists(None, None, None, None).await?;

Main Components

Structs

RemoteLibraryMusicApi
A MusicApi implementation that proxies requests to a remote MoosicBox server.

Enums

RequestError
Errors that can occur when making HTTP requests to a remote MoosicBox server.